@@ -110,7 +110,7 @@ class Build:
                     yarn_dir = self.build_dir
                 if self._shell_exec("yarn install", cwd=yarn_dir, build_step='build'):
                     return
-                if self._shell_exec("yarn run %s" % aegis.config.get('env'), cwd=yarn_dir, build_step='build'):
+                if self._shell_exec("yarn run %s" % self.build_row['env'], cwd=yarn_dir, build_step='build'):
                     return
                 build_file_version = self.next_tag
                 if self.build_row['env'] in options.build_local_envs:
@@ -190,7 +190,7 @@ class Build:
             # https://stackoverflow.com/questions/52763508/python-prevent-child-threads-from-being-affected-from-sigint-signal
             # Instead, allow Hydra to use its quitting flag to stop and let supervisor restart.
             proc_is_hydra = process.startswith(options.deploy_hydra_name)
-            if main_is_hydra and proc_is_hydra:
+            if main_is_hydra and proc_is_hydra and aegis.config.get('env') == self.build_row['env']:
                 logging.warning("Skip 'supervisorctl restart hydra' from within Hydra")
                 continue
             # Restart processes one-by-one from supervisorctl
