@@ -288,8 +288,6 @@ class AegisHandler(tornado.web.RequestHandler):
             name = "%s_%s" % (self.tmpl['env'].split('-')[0], name)
         else:
             name = "%s_%s" % (self.tmpl['env'], name)
-        aegis.stdlib.logw(self.tmpl['env'], "ENV")
-        aegis.stdlib.logw(name, "COOKIE NAME")
         return name
 
     def cookie_set(self, name, value, cookie_duration=None):
@@ -909,7 +907,10 @@ class AegisBuild(AegisWeb):
         self.enforce_admin()
         self.tmpl['builds'] = [b for b in aegis.model.Build.scan() if (not b['delete_dttm'] and b['build_target'] != 'admin')]
         self.tmpl['home_link'] = '/admin/build'
-        self.tmpl['live_build'] = aegis.model.Build.get_live_build(aegis.config.get('env'))
+        env = aegis.config.get('env')
+        if env.endswith('-admin'):
+            env = env.split('-')[0]
+        self.tmpl['live_build'] = aegis.model.Build.get_live_build(env)
         return self.render_path("build.html", **self.tmpl)
 
     @tornado.web.authenticated
@@ -990,7 +991,7 @@ class AegisBuildForm(AegisWeb):
         if aegis.config.get('env').endswith('-admin'):
             build['env'] = aegis.config.get('env').split('-')[0]
         aegis.stdlib.logw(build['env'], "SET BUILD ENV FROM PROCESS ENV")
-        # XXX This should be env-admin
+        build['build_target'] = 'application'
 
         # Create build row and add it to run on Hydra
         build_id = aegis.model.Build.insert_columns(**build)
